package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````J"(```````!``````````)"A````
M`````````$``.``)`$``&@`9``8````$````0`````````!``````````$``
M````````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"````````.`(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````&B9````````:)D`````````
M``$```````$````&````.)L````````XFP$``````#B;`0``````2`4`````
M``!P%0```````````0```````@````8```!(FP```````$B;`0``````2)L!
M```````@`@```````"`"````````"``````````$````!````%0"````````
M5`(```````!4`@```````$0`````````1``````````$`````````%#E=&0$
M````()(````````@D@```````""2````````]`````````#T``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````#B;````````.)L!```````XFP$`
M`````,@$````````R`0````````!`````````"]L:6(O;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ```$````$`````$```!'3E4```````,````'``````````0`
M```4`````P```$=.50`+R2-6J@CS,E<9#&;0&!7G_=XC5Q$```!/````!```
M``@````A$!``!<`$A"@"$`&`AD"`@@D`!`D@!(B(H!!%N@`""$\```!0````
M4P```%<```!8````7P```&````!A````8P```&0`````````9@```&<```!H
M````:@```````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[9V5#R4(/_D#M5D
MU'S9<5@<XD?&`:Q+X\"ZXY)\6.^7><+E/RSZH6Q@LP&+;VL)0]9GK\QF0D75
M[(D'<-,-%.*>VLWCGC-BV^T-.I<+?ZF<F[[:5QOAIP(*H^#[20``````````
M`````````````````````````````````P`+`$@<````````````````````
M`````P`6``"@`0````````````````"<`@``$@``````````````````````
M```@`P``$@````````````````````````!L`@``$@``````````````````
M``````!S`@``$@`````````````````````````2`P``$@``````````````
M```````````5`@``$@`````````````````````````1````(```````````
M``````````````#$`@``$@````````````````````````#<`@``$@``````
M```````````````````#`P``(@````````````````````````#5`@``$@``
M``````````````````````"\`@``$@````````````````````````"T````
M$@````````````````````````#.`@``$0````````````````````````"#
M`0``$@````````````````````````!2`P``$@``````````````````````
M``"$````$@`````````````````````````,`0``$@``````````````````
M``````#E`@``$@````````````````````````!>`@``$@``````````````
M``````````"J`0``$@`````````````````````````!`0``$0``````````
M``````````````"C`@``$@````````````````````````!G`0``$@``````
M``````````````````#C````$0`````````````````````````U`0``$@``
M```````````````````````:`@``$@`````````````````````````V`P``
M$@````````````````````````!Z`@``$@````````````````````````#"
M````$@````````````````````````"Q`0``$@``````````````````````
M```#`@``$@````````````````````````">`0``$@``````````````````
M``````#C`0``$@````````````````````````!)`@``$@``````````````
M``````````!E`@``$@`````````````````````````B`@``$@``````````
M```````````````K`@``$@````````````````````````#=`0``$@``````
M``````````````````!#`0``$@`````````````````````````M````(```
M``````````````````````!Z`P``$0````````````````````````!)`P``
M(0````````````````````````!1`@``$@`````````````````````````H
M`P``$@````````````````````````!D````$@``````````````````````
M``".`@``$@`````````````````````````O`P``$@``````````````````
M``````#-`P``$@````````````````````````"(`@``$@``````````````
M``````````"3````$@````````````````````````"?````$@``````````
M``````````````!<`0``$@````````````````````````"Q`@``$@``````
M```````````````````B`0``$@`````````````````````````1`0``$@``
M``````````````````````!6````$@````````````````````````#Y`@``
M$@`````````````````````````6`0``$@````````````````````````"3
M`0``$@````````````````````````#P````$@``````````````````````
M``#R`@``$@````````````````````````!U`0``$@``````````````````
M``````!S````$@````````````````````````#^`0``$@``````````````
M``````````!7`@``$@````````````````````````!(`P``$0``````````
M``````````````!*`P``$0````````````````````````#W`0``$@``````
M``````````````````#4````$@````````````````````````!3`0``$@``
M``````````````````````"!`@``$@`````````````````````````\````
M(`````````````````````````#,`0``$@`````````````````````````\
M`@``$@````````````````````````!#`@``$@``````````````````````
M``#J`P``$``7`*BP`0````````````````#6`P``$@`-`+!0````````@```
M```````.!```$@`-`.A#````````V`@```````!#`P``$@`-`(`@````````
M*`(```````"<`P``$@`-`!`]````````!`````````"M`P``$``7`("@`0``
M``````````````"5!```$@`-`!@]````````#`(```````#"!```$@`-`,!,
M````````[`,```````"!!```$``7`("@`0````````````````#U`P``$@`-
M`"@_````````+``````````H!```$0`/`-A1````````!`````````!G!```
M$``7`*BP`0````````````````!L!```$``7`*BP`0````````````````"-
M!```$@`-`*@[````````.`````````"B!```$@`-`/A"````````[```````
M``"T!```$@`-`$!"````````B``````````;!```$``6``"@`0``````````
M```````"!```$@`-`%@_````````'`$```````#B`P``$``6`("@`0``````
M``````````!=!```$0`6`'B@`0``````"`````````",`P``$@`-`+!1````
M````!`````````!-!```$@`-`#!1````````?``````````A!```$@`-`*@B
M```````````````````=!```(``6``"@`0````````````````"[`P``$@`-
M`,A"````````+`````````#I`P``$``7`*BP`0`````````````````W!```
M$@`-`#@\````````V`````````!T!```$@`-`'A`````````Q`$`````````
M;&EB<&5R;"YS;RXU+C(X`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?
M7V=M;VY?<W1A<G1?7P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?
M<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L
M7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!0
M97)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N
M`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R
M;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V
M7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E
M<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T7T1Y;F%,;V%D97(`<&5R
M;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!L:6)P=&AR
M96%D+G-O+C``7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!P=&AR96%D7V=E='-P
M96-I9FEC`&]P96XV-`!R96%D`&QS965K-C0`;&EB8RYS;RXV`&5X:70`<W1R
M;F-M<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R
M96%L;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L
M96X`;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?
M7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D
M97)R`&=E='5I9`!R96%D;&EN:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D
M:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C
M97-S`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]R96=I
M<W1E<E]A=&9O<FL`;&0M;&EN=7@M86%R8V@V-"YS;RXQ`%]?<W1A8VM?8VAK
M7V=U87)D`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`%]?8G-S
M7W-T87)T7U\`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N
M=7``7V5D871A`%]?8G-S7V5N9%]?`'!A<E]B87-E;F%M90!P87)?9&ER;F%M
M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A
M<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L
M`%]E;F0`7U]E;F1?7P!P87)?:6YI=%]E;G8`7U]B<W-?<W1A<G0`>'-?:6YI
M=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A
M;@!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXQ-P```````````@`"
M``(``@`"``(````"``(``@`"``(````"`````@```````@`"``(````"````
M``````(``@`"```````#`````P`"``(``@`"``,```````0``@`"``(````"
M``(``@`"``````````(````"`````@`````````"```````#``(``@`"``,`
M``````(````#``(``@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``````````$``0!D`P``$````"``
M``"7D98&```$`-@$`````````0`!`+P!```0````(````)>1E@8```,`V`0`
M```````!``$`"P(``!``````````EY&6!@```@#8!````````#B;`0``````
M`P0```````"H(P```````$";`0```````P0```````!@(P```````(B?`0``
M`````P0```````"P40```````-"?`0```````P0````````P40```````."?
M`0```````P0```````"`(`````````B@`0```````P0````````(H`$`````
M`!B@`0```````P0```````#@50```````""@`0```````P0````````84@``
M`````#"@`0```````P0```````!X4P```````#B@`0```````P0```````#`
M50```````$"@`0```````P0```````#(50```````$B@`0```````P0`````
M``#050```````%"@`0```````P0```````#850```````&"@`0```````P0`
M``````"H50```````&B@`0```````P0```````"P50```````'B@`0``````
M`P0```````#H50```````)"?`0```````00```D``````````````)B?`0``
M`````00```P``````````````*"?`0```````00``!```````````````*B?
M`0```````00``!$``````````````+"?`0```````00``!@`````````````
M`+B?`0```````00``!L``````````````,"?`0```````00``"L`````````
M`````,B?`0```````00``"P``````````````-B?`0```````00``#D`````
M`````````.B?`0```````00``$(``````````````/"?`0```````00``$8`
M`````````````/B?`0```````00``$L``````````````("=`0```````@0`
M``,``````````````(B=`0```````@0```0``````````````)"=`0``````
M`@0```4``````````````)B=`0```````@0```8``````````````*"=`0``
M`````@0```<``````````````*B=`0```````@0```@``````````````+"=
M`0```````@0```H``````````````+B=`0```````@0```L`````````````
M`,"=`0```````@0```P``````````````,B=`0```````@0```T`````````
M`````-"=`0```````@0```X``````````````-B=`0```````@0```\`````
M`````````."=`0```````@0``!(``````````````.B=`0```````@0``!,`
M`````````````/"=`0```````@0``!0``````````````/B=`0```````@0`
M`!4```````````````">`0```````@0``!8```````````````B>`0``````
M`@0``!<``````````````!">`0```````@0``!D``````````````!B>`0``
M`````@0``!H``````````````"">`0```````@0``!P``````````````"B>
M`0```````@0``!T``````````````#">`0```````@0``!X`````````````
M`#B>`0```````@0``!\``````````````$">`0```````@0``"``````````
M`````$B>`0```````@0``"$``````````````%">`0```````@0``"(`````
M`````````%B>`0```````@0``",``````````````&">`0```````@0``"0`
M`````````````&B>`0```````@0``"4``````````````'">`0```````@0`
M`"8``````````````'B>`0```````@0``"<``````````````(">`0``````
M`@0``"@``````````````(B>`0```````@0``"D``````````````)">`0``
M`````@0``"H``````````````)B>`0```````@0``"L``````````````*">
M`0```````@0``"X``````````````*B>`0```````@0``"\`````````````
M`+">`0```````@0``#```````````````+B>`0```````@0``#$`````````
M`````,">`0```````@0``#(``````````````,B>`0```````@0``#,`````
M`````````-">`0```````@0``#0``````````````-B>`0```````@0``#4`
M`````````````.">`0```````@0``#8``````````````.B>`0```````@0`
M`#<``````````````/">`0```````@0``#@``````````````/B>`0``````
M`@0``#H```````````````"?`0```````@0``#L```````````````B?`0``
M`````@0``#P``````````````!"?`0```````@0``#T``````````````!B?
M`0```````@0``#X``````````````""?`0```````@0``#\`````````````
M`"B?`0```````@0``$```````````````#"?`0```````@0``$$`````````
M`````#B?`0```````@0``$,``````````````$"?`0```````@0``$0`````
M`````````$B?`0```````@0``$<``````````````%"?`0```````@0``$@`
M`````````````%B?`0```````@0``$D``````````````&"?`0```````@0`
M`$H``````````````&B?`0```````@0``$P``````````````'"?`0``````
M`@0``$T``````````````'B?`0```````@0``$X``````````````/U[OZG]
M`P"1I`$`E/U[P:C``U_6`````/![OZG0``"0$;Y&^1#B-9$@`A_6'R`#U1\@
M`]4?(`/5T```D!'"1OD0`C:1(`(?UM```)`1QD;Y$"(VD2`"'];0``"0$<I&
M^1!"-I$@`A_6T```D!'.1OD08C:1(`(?UM```)`1TD;Y$((VD2`"'];0``"0
M$=9&^1"B-I$@`A_6T```D!':1OD0PC:1(`(?UM```)`1WD;Y$.(VD2`"'];0
M``"0$>)&^1`"-Y$@`A_6T```D!'F1OD0(C>1(`(?UM```)`1ZD;Y$$(WD2`"
M'];0``"0$>Y&^1!B-Y$@`A_6T```D!'R1OD0@C>1(`(?UM```)`1]D;Y$*(W
MD2`"'];0``"0$?I&^1#"-Y$@`A_6T```D!'^1OD0XC>1(`(?UM```)`1`D?Y
M$`(XD2`"'];0``"0$09'^1`B.)$@`A_6T```D!$*1_D00CB1(`(?UM```)`1
M#D?Y$&(XD2`"'];0``"0$1)'^1"".)$@`A_6T```D!$61_D0HCB1(`(?UM``
M`)`1&D?Y$,(XD2`"'];0``"0$1Y'^1#B.)$@`A_6T```D!$B1_D0`CF1(`(?
MUM```)`1)D?Y$"(YD2`"'];0``"0$2I'^1!".9$@`A_6T```D!$N1_D08CF1
M(`(?UM```)`1,D?Y$((YD2`"'];0``"0$39'^1"B.9$@`A_6T```D!$Z1_D0
MPCF1(`(?UM```)`1/D?Y$.(YD2`"'];0``"0$4)'^1`".I$@`A_6T```D!%&
M1_D0(CJ1(`(?UM```)`12D?Y$$(ZD2`"'];0``"0$4Y'^1!B.I$@`A_6T```
MD!%21_D0@CJ1(`(?UM```)`15D?Y$*(ZD2`"'];0``"0$5I'^1#".I$@`A_6
MT```D!%>1_D0XCJ1(`(?UM```)`18D?Y$`([D2`"'];0``"0$69'^1`B.Y$@
M`A_6T```D!%J1_D00CN1(`(?UM```)`1;D?Y$&([D2`"'];0``"0$7)'^1""
M.Y$@`A_6T```D!%V1_D0HCN1(`(?UM```)`1>D?Y$,([D2`"'];0``"0$7Y'
M^1#B.Y$@`A_6T```D!&"1_D0`CR1(`(?UM```)`1AD?Y$"(\D2`"'];0``"0
M$8I'^1!"/)$@`A_6T```D!&.1_D08CR1(`(?UM```)`1DD?Y$((\D2`"'];0
M``"0$99'^1"B/)$@`A_6T```D!&:1_D0PCR1(`(?UM```)`1GD?Y$.(\D2`"
M']:P``#P$:)'^1`"/9$@`A_6L```\!&F1_D0(CV1(`(?UK```/`1JD?Y$$(]
MD2`"']:P``#P$:Y'^1!B/9$@`A_6L```\!&R1_D0@CV1(`(?UK```/`1MD?Y
M$*(]D2`"']:P``#P$;I'^1#"/9$@`A_6L```\!&^1_D0XCV1(`(?UOU[N:G]
M`P"1\U,!J;0``/"#YD?Y]5L"J60`0/GD-P#Y!`"`TN*'!*GB(P&1X4,!D>!?
M`+G@<P&1BO__EZ```/"B``#P`/1'^4+L1_GA`P*J.@P`E*```/``W$?Y``!`
M.4`*`#33``"0M0``\/<;`/FUVD?YH`)`N5+__Y<!:%(Y(0`?,@%H$CF@`D"Y
M3?__EP)H4CGA7T"Y0@``,@)H$CDA%``1('Q]DT+__Y?E*T#Y8B("D<$``)"&
M`(!2!```\`,``/`G/$#YA&`6D:$`0/EC@!:1`1``J2$`@-)&!`"YY@"`DD`$
M`/GB7T"Y!PP!J5\$`'$-`0!4(Q``$:1X8?C#S".+(00`D5\``6L$:"/X3/__
M5$40`!%V(@*1XP,`JD(,`!$%S"6+`0``L,`.0/DA@"^1OX`?^`0`@-)]__^7
M]0,`*L`$`#1V(@*1]Y,!D<`.0/GW_O^7````\.$#%ZH`(`R1J00`E"`$`+1S
M(@*18`Y`^=O^_Y=B__^7E.9'^>`#%2KB-T#Y@0)`^4$``<IA!`"U\U-!J?5;
M0JGW&T#Y_7O'J,`#7];Z_O^7TP``D&(B`I%`#`#Y]QL`^2`#`+2U``#PP_[_
MEZ#:1_D``$"Y_/[_EQ_$*#FF__\7P`Y`^73__Y?U`P`JV/__%\`*0/E@``"T
MCPL`E-W__Q?A`Q>J````\`!`"I&`!`"4P`H`^>#Z_[2'"P"4U?__%_G^_Y<@
M`(!2B_[_EQT`@-(>`(#2Y0,`JN$#0/GB(P"1Y@,`D:```/``\$?YHP``\&/H
M1_FD``#PA,1'^<+^_Y?Y_O^7H```\`#@1_E```"T\?[_%\`#7]8?(`/5P```
MD````I'!``"0(0`"D3\``.N@``!4H0``\"'(1_E!``"T(``?UL`#7]8?(`/5
MP```D````I'!``"0(0`"D2$``,LA_$.3(?Q!BR'\09.A``"TH@``\$+\1_E"
M``"T0``?UL`#7];]>[ZI_0,`D?,+`/G3``"08`)".4`!`#6@``#P`,Q'^8``
M`+3```"0``1`^5W^_Y?:__^7(`"`4F`"`CGS"T#Y_7O"J,`#7];@__\7'R`#
MU?^#"M&H``#PXF,`D07@`)$)X`&1Y`,"JOU[`*G]`P"1`>5'^2,`0/GC3P'Y
M`P"`TJ$`0+F$0`"1HX1`^"$(P%J!`!_XOP`)ZV'\8--G_&C3YQQXDB;<>-,A
M'`A3QAQPDN/@0ZHA``:J(0`#JH&`'_@!_O]410`(D4$`0/E"(`"10P1`^40<
M0/EC``'*03!`^2$`!,HA``/*(_Q?TV$$`:HA?$"203P`^5\`!>MA_O]4!1!`
MJ2,SC](&'$&I0U"K\NNS0:DB=)W2JOQ;TZW\0M-*%06JK7D%JN$`!LHBVZWR
M(0`$BB$`!\IK`0.+*D`JBX'\0M,A>`2J2@$+BPD00/DN?$"2RP$&RHP!`XM*
M`0D+:P$%BFL!!LHA``W*3_U;TVL!!XOO%0JJ:P$,B^L!"PM/_4+3(0`*BNIY
M"JKLOT*I(0`.RG#]6],A``:+$!8+JHP!`XOO`0.+(0`,BZP!"LH!`@$+C`$+
MBK!]0))M_4+3C`$0RJUY"ZJ,`0Z++OQ;TXP!#XM+`0W*SA4!JDI]0)+O'T#Y
MS@$,"VL!`8HL_$+3:P$*RN\!`XMK`1"+T/U;TXQY`:H0%@ZJ:P$/BZ$!#,H+
M`@L+T/U"TR$`#HH.>@ZJ[T-$J:U]0)(A``W*(0`*B^H!`XMO_5O3(0`*BXH!
M#LKO%0NJC'U`DDH!"XKO`0$+2@$,RF']0M,0`@.+*W@+JDH!#8O!`0O*2@$0
MB\Y]0)+P*T#Y[?U;TR$`#XJM%0^J(0`.RO']0M.M`0H++WH/J@H"`XLA``R+
M(0`*BVH!#\JP_5O3:WU`DDH!#8H0%@VJ2@$+RA`"`0M*`0Z+L?U"T^&[1:DM
M>@VJ#/Y;TQ'^0M.,%1"J(0`#BTH!`8OA`0W*(0`0BN]]0)(A``_*C`$*"S!Z
M$*K*`0.+(0`+BX[]6],A``J+J@$0RDH!#(JM?4"2SA4,JDH!#<K.`0$+2@$/
MB^&_1JF1_4+3+'H,JLO]6]-K%0ZJT?U"TR$``XM*`0&+`0(,RB$`#HH0?D"2
M(0`0RFL!"@LN>@ZJZ@$#BR$`#8MO_5O3(0`*BXH!#LI*`0N*C'U`DN\5"ZI*
M`0S*[P$!"TH!$(OAPT>I<?U"TRMZ"ZKM_5O3K14/JO']0M,A``.+2@$!B\$!
M"\HA``^*SGU`DB$`#LJM`0H++WH/J@H"`XLA``R+L/U;TR$`"HMJ`0_*2@$-
MBFM]0)(0%@VJ2@$+RA`"`0M*`0Z+X;M(J;']0M,M>@VJ#/Y;TXP5$*H1_D+3
M(0`#BTH!`8OA`0W*(0`0BN]]0)(A``_*C`$*"S!Z$*K*`0.+(0`+BX[]6],A
M``J+J@$0RDH!#(JM?4"2SA4,JDH!#<K.`0$+2@$/B^&_2:F1_4+3+'H,JLO]
M6]-K%0ZJ(0`#B^\!`XM*`0&+`0(,RFL!"@L0?D"2(0`.BB$`$,IJ_5O3(0`-
MB\W]0M.N>0ZJ(0`/BTH5"ZK2?4"22@$!"X$!#LHA``N*C'U`DB$`#,I1_5O3
M(0`0BS$6"JKMPTJIK0$#BP,"`XLA``V+;?U"TS%`,8NK>0NJ+WY`DL$!"\HA
M``J*[?U;TR$`$LHA``R+K14/JB$``XM#_4+3+4`MBV%X"JJP?4"2:@$!RN-?
M0/E*`1%*#OY;TTH!$HMC``*+SA40JDH!`XOL_4+33D$NBXQY#ZK1?4"2+P`,
MRNIC0/GO`0U*+?Y;T^M!*XM*`0*+K141JF,!"HL*_D+3;4`MBT-Y$*JP?4"2
MB@$#RN]G0/E*`0Y*"_Y;TTI!(8MK%1"JX0$"BTH!`8LA_D+32T$KBRIX$:IO
M?4"280`*RNYK0/DA``U*[?U;TR%`+(O.`0*+K!4/JB$`#HL-_D+3+$`LBZ%Y
M$*J0?4"23@$!RNUO0/G.`0M*"_Y;T\-!(XNM`0*+:Q40JF,`#8OM_4+3:T`K
MBZ-Y#ZIO?4"2+@`#RNUS0/G.`0Q*[/U;T\I!*HNM`0*+C!4/JDH!#8L-_D+3
M3$$LBZIY$*J0?4"2;@`*RNUW0/G.`0M*"_Y;T\%!(8NM`0*+:Q40JB$`#8OM
M_4+3*T`KBZ%Y#ZIO?4"23@$!RNU[0/G.`0Q*[/U;T\-!(XNM`0*+C!4/JF,`
M#8L-_D+3;$`LBZ-Y$*J0?4"2+@`#RNU_0/G.`0M*"_Y;T\I!*HNM`0*+:Q40
MJDH!#8OM_4+32T$KBZIY#ZIO?4"2;@`*RNV#0/G.`0Q*[/U;T\%!(8NM`0*+
MC!4/JB$`#8L-_D+3+$`LBZ%Y$*I.`0'*D'U`DLX!"TK#02.+"_Y;T^V[4*EK
M%1"JK0$"BV,`#8OM_4+3:T`KBZ-Y#ZIO?4"2+0`#RJP!#$KM_5O3BD$JBZT5
M#ZK,`0*+2@$,BPS^0M--02V+BGD0JK!]0))L``K*[H]`^8L!"TH,_EO384$A
MBXP5$*K+`0*+(0`+B^O]0M,L0"R+87D/JHM]0))/`0'*[I-`^>\!#4IM_5O3
MXT$CB\X!`HNM%0NJ8P`.BP[^0M-M0"V+PWD0JK!]0)(O``/*[I=`^>\!#$H,
M_EO3ZD$JB\X!`HN,%1"J2@$.BV[]0M-,02R+RWD+JHI]0))O``O*[IM`^>\!
M#4I-_5O3X4$AB\X!`HNM%0JJ(0`.BP[^0M,M0"V+P7D0JNZ?0/EO`0'*[P$,
M2K!]0)+.`0*+XT$CBV,`#HM._4+3RGD*J@S^6],O``K*C!40JN\!#4KK02N+
M;$`LB^X_5*F#?4"2;?Q;TZT5`ZK.`0*+[P$"BVL!#HL._D+3;4$MB\MY$*I0
M`0O*KGU`D@P"#$IP_$+3@4$AB\S]6],#>@.J(0`/BXP5#JKOJT#YC`$!"V$!
M`\HM``U*P?U"TR%X#JJJ02J+X@$"BXW]6],Q?$"2KA4,JD(!`HMM?$"2:@`!
MJLX!`@OOKT#YH@$1BDH!#(J#_4+32@$"JH*;E])BX['R8W@,JDM!*XOJ`0*+
M;'Q`DFL!"HLJ``.J(0(,BDH!#HK0_5O32@$!JA`6#JI*`0V+$`(+"^\W5JG!
M_4+3(7@.JBY\0)+K`0*+#_Y;TTH!"XOO%1"J:P`!JN\!"@N#`0Z*:P$0BFL!
M`ZH#_D+3J@$"BV-X$*IK`1&+[?U;TW!\0))K`0J+K14/JBH``ZKQNT#YK0$+
M"\$!$(I*`0^*2@$!JN']0M,A>`^J*P("BTH!#(NL_5O3+WQ`DDH!"XN,%0VJ
M:P`!JO&_0/F,`0H+`P(/BFL!#8IK`0.JH_U"TV-X#:J*_5O3:P$.BRX"`HM-
M%0RJ:P$.BRH``ZIN?$"2\<-`^:T!"POA`0Z*2@$,BDH!`:J!_4+3(7@,JJO]
M6]-*`1"+,`("BVP5#:I*`1"+:P`!JC!\0)+QQT#YC`$*"\,!$(IK`0V*:P$#
MJJ/]0M-C>`VJBOU;TVL!#XLO`@*+314,JFL!#XLJ``.J;WQ`DO'+0/FM`0L+
M`0(/BDH!#(I*`0&J@?U"TR%X#*JK_5O32@$.BRX"`HML%0VJ2@$.BVL``:HN
M?$"2\<]`^8P!"@OC`0Z*:P$-BFL!`ZJC_4+38W@-JHK]6]-K`1"+,`("BTT5
M#*IK`1"+*@`#JG!\0)+QTT#YK0$+"\$!$(I*`0R*2@$!JH']0M,A>`RJJ_U;
MTTH!#XLO`@*+;!4-JDH!#XMK``&J+WQ`DO'70/F,`0H+`P(/BFL!#8IK`0.J
MH_U"TV-X#:HJ`@*+:P$.BX[]6]-M?$"2:P$*B\X5#*HJ``.J\=M`^<X!"POA
M`0V*2@$,BDH!`:J!_4+3(7@,JLO]6]-*`1"+,`("BVP5#JI*`1"+:P`!JC!\
M0)+QWT#YC`$*"Z,!$(IK`0Z*:P$#JL/]0M-C>`ZJBOU;TVL!#XLO`@*+3A4,
MJFL!#XLJ``.J;WQ`DO'C0/D!`@^*2@$,BLX!"PM*`0&J@?U"TR%X#*HK`@*+
M2@$-BRQ\0))*`0N+:P`!JFL!#HKC`0R*:P$#JLW]6]-K`1"+K14.JO'#7*FM
M`0H+P_U"TV-X#JIN?$"2*@("B[']6],Q%@VJ:P$*BRH``ZHK`@L+@0$.BDH!
M#8I*`0&JH?U"TR%X#:H0`@*+2@$/BV_]6],M?$"22@$0B^\5"ZIC``&J\.]`
M^>\!"@MC``N*R@$-BF,`"JIJ_4+32GD+JF,`#(OQ_5O3#`("BS$6#ZHK``JJ
M8P`,BTQ]0)(A`@,+:P$/BJ,!#(IK`0.JX_U"TV-X#ZIK`0Z+\#]>J2[\6]/.
M%0&J2@$#JDH!`8KQ^T#Y$`("BVL!$(O+`0L+;GQ`DI`!#HI*`1"J</U;TTH!
M#8L0%@NJ[0$"BR("`HM*`0V++?Q"TZ%Y`:I003"+"GY`DB]\0))C``&JS0$/
MBF,`"XIR_4+38P`-JDW]6]-C``R+K14*JF(``HM+>@NJ34`MBR$`"\JQ?4"2
M(0`02N+_0/G#.IC2+/Y;TT-,N?(A``Z+0@`#BXP5$:HA``*+3OU"TRQ`+(O*
M>0JJD'U`DF(!"LKA`T'Y0@`-2@W^6]-"``^+(0`#BZT5$*I"``&++OY"TTU`
M+8O!>1&JKGU`DD\!`<KB!T'Y[P$,2LS]6]/K02N+0@`#BXP5#JIK`0*+#_Y"
MTVQ!+(OB>1"JCWU`DC```LKK"T'Y$`(-2NW]6],*0BJ+:P$#BZT5#ZI*`0N+
MT/U"TTU!+8L+>@ZJKGU`DE``"\KJ#T'Y$`(,2LS]6],!0B&+2@$#BXP5#JHA
M``J+\/U"TRQ`+(L*>@^JCWU`DG`!"LKA$T'Y$`(-2NW]6],"0B*+(0`#BZT5
M#ZI"``&+T/U"TTU`+8L!>@ZJKGU`DE`!`<KB%T'Y$`(,2LS]6],+0BN+0@`#
MBXP5#JIK`0*+\/U"TVQ!+(L">@^JCWU`DC```LKK&T'Y$`(-2NW]6],*0BJ+
M:P$#BZT5#ZI*`0N+T/U"TTU!+8L+>@ZJKGU`DE``"\KJ'T'Y$`(,2LS]6],!
M0B&+2@$#BXP5#JHA``J+\/U"TRQ`+(L*>@^JCWU`DG`!"LKA(T'Y$`(-2NW]
M6],"0B*+(0`#BZT5#ZI"``&+T/U"TTU`+8L!>@ZJKGU`DE`!`<KB)T'Y$`(,
M2LS]6],+0BN+0@`#BXP5#JIK`0*+\/U"TVQ!+(L">@^JCWU`DC```LKK*T'Y
M$`(-2NW]6],*0BJ+:P$#BZT5#ZI*`0N+T/U"TTU!+8L+>@ZJKGU`DE``"\KJ
M+T'Y$`(,2LS]6],!0B&+2@$#BXP5#JHA``J+\/U"TRQ`+(L*>@^JCWU`DG`!
M"LKA,T'Y$`(-2NW]6],"0B*+(0`#BZT5#ZI"``&+T/U"TTU`+8L!>@ZJKGU`
MDE`!`<KB-T'Y$`(,2LS]6],+0BN+C!4.JD(``XMK`0*+\/U"TVM!+(L">@^J
M;WU`DC```LKL.T'Y$`(-2NW]6],*0BJ+C`$#B]#]0M.M%0^J2@$,BPQZ#JI-
M02V+4``,RJY]0)(0`@M*ZS]!^<K]6],!0B&+2A4.JFL!`XOP_4+3(0`+BPMZ
M#ZHJ0"J+D`$+RD%]0)(0`@U*[T-!^2W\6],"0B*+K14!JN\!`XO0_4+30@`/
MBPYZ#JI-0"V+<`$.RN]'0?FB?4"2"@(*2C#\0M/O`0.+3$$LBTK\6],!>@&J
MC`$/BTH5`JKO2T'Y2@$,"\P!`<I0_$+3C0$-2NP!`XNK02N+0_U;TVL!#(MC
M%`JJ`GH"JF,`"PL(Y4?Y1@`&"V4`!0O)`0D+A``*"R$`!PL%$`"I!@0!J>-/
M0?D"`4#Y8@`"R@D0`/F"``"U_7M`J?^#"I'``U_6@/K_EQ\@`]7]>[RI_0,`
MD?-3`:F@!@"TH@``T/=C`ZE"^$?Y6`!`^5@&`+3U6P*I%0"`4@(`0#E?]`!Q
M1!A`>@$#`%03`T#Y$P(`M/<#`:KV`P"JM7Y`D_0#&*H?(`/5X@,5JN$#%JK@
M`Q.J.?K_EX```#5@:G4X'_0`<0`"`%23CD#X\_[_M?5;0JGW8T.IX`,3JO-3
M0:G]>\2HP`-?UO4#`*JB'D`X7_0`<4080'JA__]4M0(`2^/__Q>``AC+M08`
MD7,"%8L`_$.3X`(`N>`#$ZKS4T&I]5M"J?=C0ZG]>\2HP`-?UA,`@-+I__\7
M$P"`TO=C0ZGF__\7'R`#U?U[O*G]`P"1]5L"J;8``-#U`P"JP.9'^?-3`:FS
M``#0]-,`D0$`0/GA'P#Y`0"`TG/Z1_GA`Q2JX`,5JK/__Y<``@"T8@)`^>,W
M@+E`#`.+`01`^4%X(_CA_O^T'R`#U0`@`)$!!$#Y`0``^:'__[7A`Q2JX`,5
MJJ3__Y=`_O^UUN9'^>$?0/G``D#Y(```RJ```+7S4T&I]5M"J?U[Q*C``U_6
M%_K_E_U[N:G]`P"1\U,!J;0``-#S`P"J]5L"J?4#`:KW8P.I^6L$J8'F1_F@
M`D`Y(@!`^>(W`/D"`(#2'_0`<;46E9K@`Q6JD?G_E_8#`*KADP&1X`,3JH/_
M_Y=@"`"T]P,`JHKY_Y<?`!;K`@<`5/AG@+FY``#0&/-]TV`"0#D?]`!Q!!A`
M>J`,`%3A`Q.J'R`#U2`<0#@?]`!Q!!A`>J'__U0A`!/+(7Q`DSG[1_G`"@"1
M```!BS8#0/FL^?^7P&HX^(`+`+3C9X"YX`,3JB(#0/D!%$`X0GAC^#_T`'$D
M&$!Z00``.<```%0!%$`X01P`.#_T`'$D&$!Z@?__5*$'@%(``(#2010`.*%J
M8#A!:"`X``0`D:'__S4``(!2E.9'^>(W0/F!`D#Y00`!RF$(`+7S4T&I]5M"
MJ?=C0ZGY:T2I_7O'J,`#7]8``(#2'R`#U:%J8#CA:B`X``0`D:'__S7N__\7
MN0``T/LK`/D@^T?Y&`!`^0`#0/E`!0"TX0,8J@``@%("```4X`,7*B*,0/@7
M!``1HO__M0`,`!$`?'V3H0``\"*(0+E"`@`U(@"`4B*(`+EM^?^7^P,`JH`#
M`+3Z?D"3X0,8JECS?=/B`QBJ)OG_ER#[1_D;``#Y6@<`D7][.OCW9P"Y^RM`
M^:/__Q?A`P"JX`,8JHSY_Y?[`P"J(/M'^1L``/D[`0"T^GY`DUCS?=/R__\7
M`0"`TJ/__Q<``H#2%P"`4M[__Q?[*T#Y``"`$KK__Q?[*P#YA_G_E_U[LJG]
M`P"1\U,!J;0``-"!YD?Y(@!`^>)O`/D"`(#2P```M/5;`JGU`P"J`0!`.4$!
M`#7U6T*IE.9'^>%O0/F``D#Y(```RN`(`+7S4T&I_7O.J,`#7]88^?^7]@,`
MJJ#^_[3W8P.I%P``T!@``-#W8@B1&(,(D?EK!*GZ8P&1X`,6JJGY_Y>`!0"T
M$TP`D>$#%ZK@`Q.J@/G_ER#__S3A`QBJX`,3JGSY_Y>@_O\TX`,5JN7X_Y?Y
M`P"JX`,3JN+X_Y<``!D+``@`$0!\0),6^?^7Y0,3JN0#%:H#``#08Z`(D?D#
M`*H"`("2(0"`4MKX_Y?B`QJJX0,9J@``@%+>^/^7'P0`,:```%3@:T"Y``P4
M$A\00'$``@!4X`,9JK;Y_Y?@`QFJ>/G_E^`#%JI^^?^7P/K_M>`#%JHS^?^7
MX`,5JEWY_Y?U6T*I]V-#J?EK1*FY__\7X`,9JJG__Y?Q__\7]5L"J?=C`ZGY
M:P2I*OG_EQ\@`]7]>[6IX0,`JOT#`)'S4P&ILP``T/0#`*ICYD?YXJ,`D0``
M@%)D`$#YY%<`^00`@-)4^?^7X`$`->$[0+D"`)12(0P4$C\00'$D$$)Z8`$`
M5'/F1_GB5T#Y80)`^4$``<J!`0"U\U-!J?U[RZC``U_6``"`4O?__Q?@`Q2J
M00"`4ASY_Y<?``!QX!>?&O'__Q<$^?^7'R`#U1`*@M+_8S#+XO^!TOU[`*G]
M`P"1\U,!J;,``-!CYD?Y]5L"J?4C`9'W8P.I]@,`JO@#`:ID`$#YY"<(^00`
M@-+A`Q6J````T`#`")&+^/^7'P``<:T%`%0"!`!1H0``T"'81_FCRF(X-P!`
MN4,#`#4"!``T5'Q`D^$%@%+B`Q2JX`,5JD'Y_Y=``P"TX`,7*L[X_Y?C`Q2J
MX@,5JN$#%JI"^?^7<^9'^>$G2/E@`D#Y(```RL`#`+40"H+2_7M`J?-30:GU
M6T*I]V-#J?]C,(O``U_6X@,`*N$%@%+@`Q6J5'Q`D^(#%*HH^?^7`/W_M>`#
M%RJU^/^7X@,8JN$#%JJ2^/^7Z/__%Z```-``V$?Y%P!`N>`#%RJL^/^7X@,8
MJN$#%JJ)^/^7W___%[?X_Y?]>[^IH```T/T#`)$`V$?Y``!`N:'X_Y>B``#0
M`P``T/U[P:@!``#00M1'^6.`!Y$A``F1W?C_%_U[OJG]`P"1\PL`^;,``-!S
MVD?Y8`)`N9+X_Y?K__^78`)`N8_X_Y?S"T#Y!```T/U[PJB$0!:1`@``L.,#
M!*I"`#.1`0``T`4`@%(A@`F1Y/C_%Q\@`]40"H32_V,PRP`(@M+]>P"I_0,`
MD?-3`:FS``#0].,`D?5;`JGV8R"+%0"`TF#F1_D!`$#YX2<0^0$`@-)#^/^7
MY`,`*@4``-`#``#0I>`)D6,`"I$B`(+2(0"`4N`#%*H*^/^7X`,4JN$#%JH"
M`(+2$OC_EX`!^#?T`P"J``0`$0!\0),U^/^7]0,`JL```+24?D"3X0,6JN(#
M%*KK]_^7OVHT.'/F1_G@`Q6JXB=0^6$"0/E!``'*X0``M1`*A-+]>T"I\U-!
MJ?5;0JG_8S"+P`-?UEWX_Y?*__\7'R`#U1`>@M+_8S#+_7L`J?T#`)'W8P.I
MN```T`+G1_GS4P&I\P,!JOLK`/GADP&1^P,`J@```-!#`$#YXW<(^0,`@-(`
M0`J1R_W_E_0#`*KA!8!2X`,;JIGX_Y=``@"T````T.$#&ZH`@`J1*O[_E^`#
M&ZH8YT?YXG=(^0$#0/E!``'*`0P`M1`>@M+]>T"I\U-!J?=C0ZG[*T#Y_V,P
MB\`#7];@`QNJ]5L"J18``-#Y:P2INO?_E\'""I'Y`P`JX`,3JK+W_Y?S`P"J
MH`8`M!H``-`7``#06F,(D??B"I'UHP.180)`.2$&`#2T``"TX0,3JN`#%*H]
M^/^7@`0`-.`#$ZJF]_^78L(@B^$#`"I`\%\X'[P`<>$``%0A!`!18L(ABW_*
M(3A"\%\X7[P`<6#__U0B!P`100`!"S_\/W$,`P!4Y`,3J@,``-#F`QNJ8P`+
MD>4#%ZH"`(+2(0"`4N`#%:J2]_^7XJ,!D>$#%:H``(!2EO?_EZ```#7A>T"Y
M(0P4$C\@0'%``@!4P<(*D0``@-)^]_^7\P,`JD#Z_[7U6T*I^6M$J:[__Q?4
M``"TX0,:JN`#%*H-^/^7@/[_-!\@`]7S`QJJ(0"`4MK__Q<A`(!2X`,5JOGW
M_Y>`_?\UX0,5J@```-``@`J1ROW_E^`#%:K6]_^7]5M"J?EK1*F=__\7]5L"
MJ?EK!*G8]_^7'R`#U0$`0#GB`P"JX0``-!\@`]4`!`"1/[P`<4(0@)H!`$`Y
M@?__->`#`JK``U_6'R`#U8`(`+3]>[ZI_0,`D?,+`/GS`P"J`0!`.2$'`#1/
M]_^7``0`T6("`(M_`@+K(@,`5&!J8#@?O`!QH```5!(``!1``$`Y'[P`<>$!
M`%1"!`#1?P("ZV'__U1``$`Y'[P`<>`$`%3S"T#Y````T/U[PJ@`X`J1I??_
M%T``0#D?O`!QH`$`5$($`-%_`@+K8___5'\"`NL@_O]40@0`T7\"`NL"`0!4
M'R`#U4``0#D?O`!Q@0``5$($`-%_`@+K8___5$(`$\L``(#200@`D3\$0/$(
M`0!4H```T`2@`I%"!`"1X0,3JN`#!*H#`(+25_?_E_,+0/G]>\*HP`-?UO,+
M0/D```"P_7O"J`!@")%_]_\7````L`!@")%\]_\7'R`#U?U[N*D!``"P(8`'
MD?T#`)'S4P&ILP``L````+!CYD?Y]5L"J0`@"Y'W8P.I%@``L!<``+!F`$#Y
MYC\`^08`@-(8``"P)AQ!J>8?!:D4``"P)!1"J>07!JDA8$!YX>,`>92B#)'U
M,P&1*/W_EP```+``8`N1)?W_EP```+``@`N1(OW_EP```+``P`N1'_W_E\#B
M"Y$=_?^7````L``@#)$:_?^7X$(*D1C]_Y<`8PR1%OW_E^`#%*H4_?^7````
ML`#@#)$1_?^7````L`"`"I$._?^7````L.$#%:H`(`V1S/S_EX```+3A`P"J
MX`,4JC#]_Y<```"PX0,5J@"`#9'$_/^7H```M.$#`*H```"P`.`-D2?]_Y<`
M``"PX0,5J@`@#I&[_/^70`(`M.$#`*K@0@J1'_W_E\#B"Y$!``"P(0`/D1O]
M_Y=SYD?YX3]`^6`"0/D@``#*0`,`M?-30:GU6T*I]V-#J?U[R*C``U_6````
ML.$#%:H`8`Z1I?S_EZ```+3A`P"J`&,,D0G]_Y?J__\7`0``L/1#`9'@AP&1
M(<`.D4(!@-+L]O^78/S_-8%N`)$`8PR1_OS_E]___Q<2]_^7'R`#U?U[O:G]
M`P"1\U,!J;,``+"T``#08>9'^8`20+DB`$#YXA<`^0(`@-(?!``Q(`$`5'/F
M1_GB%T#Y80)`^4$``<HA`@"U\U-!J?U[PZC``U_6X9,`D0```+``8`R1>_S_
ME^$#`*H``(!2H0``M"``0#D?P`!Q!!A`>N`'GQJ`$@"Y[/__%^_V_Y?]>[^I
M_0,`D9#V_Y</]_^7@```M/U[P:@``$#YP`-?U@``@-+]>\&HP`-?UA\@`]7]
M>[NI_0,`D?-3`:FS``"PX1,!D6+F1_GU6P*I%0``L/<;`/FW(@^1]@,`JN`#
M%ZI#`$#YXR<`^0,`@-)5_/^7@```M`$`0#GT`P"JP0$`->$#%JJ@(@^1MOS_
MEW/F1_GA)T#Y8`)`^2```,K@`P"U\U-!J?5;0JGW&T#Y_7O%J,`#7];A`Q:J
M,/?_EX#^_[7@`Q:J2?;_E_4#`*K@`Q2J1O;_EZ`"`(L`"`"1>_;_E^8#%*KD
M`Q:J!0``L`,``+"EP`J18P`+D0(`@)+U`P"J(0"`4CWV_Y?A`Q6JX`,7JI3\
M_Y?>__\7J/;_EQ\@`]40.I#2_V,PRZ(``-!"0`"1!P*0TN1C)XO]>P&I_4,`
MD4BD0*GU6P.IM@``L/EK!:GZ`P"J^7,"D<#F1_GS4P*IX0,9JO=C!*D8``"P
MZ"<';04`0/F%W`#Y!0"`T@!#"I%*#$#YZ"<*J>I;`/E()$*IZ"<-J48<0ZGF
M'PZI1!1$J>07#ZE*+$6IZJ\+J4(P0/GB9P#Y`_S_EX```+0!`$`Y\P,`JF$A
M`#7[<P:IC?__E_0#`*J@'`"TX`,4J@/V_Y<`^'_3``0`D3CV_Y>$`D`Y^P,`
MJJ0!`#05``"P\P,;JK6"#Y$?(`/5X`,3JN,#%:H"`("2(0"`4OCU_Y=S"@"1
MA!Y`."3__S7@:T#Y8`H`M/1C`Y$#```4@(9`^.`)`+3A`QFJW_O_E_,#`*I@
M__^T`0!`.2'__S0P_?^7X/[_-.`#$ZI-]O^7\P,`JF`(`+3@`Q.JW?7_E_0#
M`*K@`QNJVO7_EQ0`%`N4$A`1%P``L)1^0)/@`Q2J#/;_EPD`9Y[G`QNJY`,3
MJN7B"I$"`("2(0"`4@8``+`#``"PQJ`/D6/`#Y'-]?^7(`%FG@$X@%*V]O^7
M'P0`,:$``%2K]O^7!0!`N;]$`''!%@!4(0%FGO4#!)'B`Q6J``"`4F?V_Y?S
M`P`JX`4`-*```+`D`6:>0P-`^>@#9YX`T$?Y`@``L"$`@%)"`!&1``!`^3_V
M_Y?[<T:I`0*0TM;F1_GA8R&+``%FGB+<0/G!`D#Y00`!R@$U`+40.I#2_7M!
MJ?-30JGU6T.I]V-$J?EK1:GH)T=M_V,PB\`#7];U@P*1%`"`4K/:=/BS`0"T
M8`)`.6`!`#24!@`1X`,3JN#\_Y<@__\TX`,3JOWU_Y?S`P"J(/;_M;/:=/BS
M_O^U$P"`TJW__Q?@$T&Y``P4$A\00''A^?]4^QM!N9WU_Y=_`P!K8?G_5.`3
M0;D`(``2'P`'<>'X_U3@`Q2JM?7_EP@`9Y[A`QFJ````L`!@$I%N^_^7P`\`
MM%0#0/GA]?^7X0,`JN`#%*J,_?^7]`,`JN`.`+3@`Q2J;O7_E_D#`*H?#`!Q
M[0$`5`!\0),!``"P`!``T2&`$I&``@"+^?7_EP`!`#4_$P!Q@"4`5"`3`%&`
MPB"+`/!?.!^\`''@)`!4P/[_E\```#7@`Q2J`0"`4C#V_Y?Z`P`JX`L`-0$`
M`+`A``^1````L`!@#)&O^_^7]^(*D8/U_Y?F`P`J)`%FG@`!9IX'``"PYT`6
MD?D#!ZKE`Q>J`P``L`(`@))C`!.1(0"`4A0``+#U`Q>J1?7_EY1"$Y$1```4
M)O;_EP``0+D?1`!Q00(`5&[U_Y?F`P`J)`%FG@`!9I[Y`P#Y<P8`$><#$RKE
M`Q6JXP,4J@(`@)(A`(!2,_7_EP`!9IX!.(!2'/;_EQ\$`#&`_?]4(`%FGMCU
M_Y<!`6:>`$,*D8/[_Y<``6:>M?[_E_MS1JET__\7]>,"D1,`@%*@VG/X@`$`
MM',&`!'A`QFJ$/O_EV#__[0!`$`Y(?__-(+U_Y?T`P"J`.+_M:#:<_C`_O^U
MH`&`TDCU_Y<4``"P^P,`JF0*@%*48@^1#___%Z```+`D`6:>0P-`^>@#9YX`
MT$?Y`@``L"$`@%)"`!"1``!`^9'U_Y?[<T:I4O__%Y#^_Y?@`Q.J:/7_EP@`
M9YY-__\75`-`^8G__Q="`(!2(0*`DODC!Y%0]?^7X0,9JL(`@-+@`QHJP/7_
ME^`C1SF````UX"='.1\,`7&@&0!4`@"`4@$`@-+@`QHJ0_7_EZ#B`)$E8(32
M(W&5TL*?F]+!CHK2_.,$D>!#`/D`/IS2I>BL\J/YO?)"%[/R00:B\D!ZN/+E
M#Q"IX@<1J>"3`/G__Q*I_WL!N0(`D-+A`QFJX`,:*J'U_Y?[`P"J'P``<?,#
M`"I-"`!4Y8M2J6%_0)/@>T&YHPP!"[\``^M"E(*:071!B^.'$JF`$0`T`0B`
M4C,``$M_`Q-KX4-`^7/3DQIT?D"3(,`@B^(#%*KA`QFJKO3_E^![0;E@`@`+
MX'L!N1\``7$A_/]4<P,32^`#%:H[`Q2+<?;_EW_^`''M$`!4<P(!46!^!E/@
MCP"Y%&0:4Y0"`9%T`Q2+9A]`J88?`*G@`Q6J8@]!J8(/`:E[`P&19A]^J88?
M`JEB#W^I@@\#J5[V_Y=_`Q3K@?[_5."/0+ES&@!+X$-`^0,)@-)B?D"3X0,4
MJL7T_Y?S>P&Y`@"0TN$#&:K@`QHJ8/7_E_L#`*H?``!Q\P,`*@SX_U3@`QHJ
M`O7_E^&70/GB#X`2\RM!N?0S0;DA(`-3<PK`6B`$`!&4"L!:'^``<8++(3@M
M"P!4`@B`4D(``$L!`(!2N>(`D4)\0),@PR"+R/3_E^`#%:HV]O^7X$,(D1_\
M,JF__@2IO_X%J;\V`/G@`Q6J]',!N?-W`;DM]O^7Y@,$D>4#0;GC"T&Y^F,&
MD>(30;D5``"PX1M!N:4(P%K@(T&Y8PC`6N0/1#E"",!:(0C`6L4,$"G"!!$I
MLX(/D0`(P%I9HP"1]`,:JO4'!I'@DP&Y`@``%*060#C@`Q2JXP,3J@(`@)(A
M`(!2E`H`D53T_Y<_`Q3K`?__5"0!9IX``6:>Y@,:JN7B"I$"`("2(0"`4@<`
M`+`#``"PYT`6D6/`$I'_`P<Y1O3_ER`!9I[P]/^7`0%FG@!#"I&;^O^7``%F
MGLW]_Y?[<T:IC/[_%_L#&:J'__\760=`^3G;_[3@`QFJ,_3_EQ\,`/&IVO]4
M`!``T0$``+`@`P"+(:`2D<#T_Y<?``!QE!*9FLW^_Q?T`QNJCO__%Z/B`)$"
M!X!20@``2P$`@%)@P""+0GQ`DW#T_Y>O__\7X"M'.1\$`7%!YO]4X"]'.1\,
M`7'AY?]4X#-'.1\@`7&!Y?]4X#='.1\4`7$AY?]40@"`4B$'@)+@`QHJ:_3_
ME^$#&:K@`QHJ(@6`TMOT_Y<D`6:>``%FGN8#&:KEX@J1!P``L`,``+#G0!:1
M8\`2D0(`@)(A`(!2!/3_E];^_Q?[<P:I<?3_E_U[N*F@``"P_0,`D?=C`ZFX
M``"P\U,!J1/;1_GU6P*I`>1'^?EK!*G[<P6I^],!D6`"0+DB`$#YXC\`^0(`
M@-)0]/^7]`,`JF`"0+E-]/^7@>)".0'D`CD```"PX0,;J@#@"Y'9^?^7@```
MM`$`0#D_Q`!Q8!,`5-#\_Y<7VT?YX`)`N3_T_Y<!``"P8P&`4B&@$Y$B`(!2
M4O3_E^`4`+2\``#0EB,"D>@G!FWS`D"Y``A`^<$&0+D_!`!Q"11`_<T%`%09
M@(!2%0"`4C0`@%(9!*!R"@``%``!9IY!"$#Y6/3_E\$&0+D@!``UE`8`$;4&
M`!$_`!1KK0,`5.`#$RH@]/^7(0%FG@,`@%*B?D"3A/3_E_H#`*J`$@"T`@!`
M^<,&0/E`#$"Y\P)`N0``&0H?`!!Q:-AT_`#]_U3@`Q,J$/3_ET$#0/E#`(!2
M`@"`TOSS_Y?A`P"J``%FGO,"0+DX]/^7P09`N2#\_S0@!`!1'P`5:\`+`%3H
M)T9MX`,3*@#T_Y=C`(!2`0``L"(`@%(AP!.1$_3_E_,#`*J@`0"T%-M'^8`"
M0+GV\_^780I`^0(``+!"X!.1(0!`^='S_Y=@"D#Y``!`^0`,0+G@#K`W%-M'
M^8`"0+GJ\_^7`0``L&,`@%(A`!21(@"`4OWS_Y?S`P"JH`$`M````+#A`QNJ
M`(`*D7'Y_Y?U`P"J@`)`N=4+`+3;\_^780I`^>(#%:HA`$#YM_/_EQC;1_F4
M(P*1``-`N=/S_Y?S`P"J``-`N=#S_Y<B`(!2`0``L"$@%)$(]/^7`@``L.$#
M`*I"@!21X`,3JJ?S_Y<``T"YQ?/_EQ_D`CGA`QNJ````L`!`"I%2^?^7@`H`
M^?,#`*K`!0"T`3B`4N`#$ZI&]/^7`00`$3\$`'$$B%%Z`0D`5*```+`:Y$?Y
MX3]`^4`#0/D@``#*``@`M?-30:GU6T*I]V-#J?EK1*G[<T6I_7O(J,`#7]8`
M!$`YP.S_-&3__Q<_!`!Q3?3_5!;;1_F5(P*1-`"`4@(``!33`D"YX`,3*IWS
M_Y<A`6:>E`8`$5;S_Y>@!D"Y'P`4:PS__U0`VT?YZ"=&;1,`0+F2__\7O```
MT/,"0+F/__\7@`9`^?C\_Y>`"@#Y\P,`JN#Y_[4```"0`*`4D>@G!FW'\_^7
M`=M'^8`C`I$S`$"Y`01`N2`$`%$?`!5KP>__5-K__Q=^\_^7@","D6(*0/D!
M!$#Y0`!`^2$`0/F&^O^7H?__%X`"0+EU\_^780I`^2$`0/G*\_^7A?__%^@G
M!FU_\_^7G","D>@G!FWC`P`JX@,3J@```)"!!T#Y`$`5D2$`0/FF\_^7'R`#
MU?U[OJG]`P"1\U,!J?0#`*JF^_^7`0!`.?,#`*K!```T``0`D3^\`'%S$H":
M`0!`.8'__S57_/^7GP(`\0080'J!``!4\U-!J?U[PJC``U_6@`)`.8#__S0!
M``"0X`,3JH(`@-(AH`^1+O/_E\#^_S7@`Q2J\U-!J?U[PJC/^?\7_7N\J?T#
M`)'S4P&IM```D)0"+9'U6P*IM0``D+7B+)&4`A7+]@,`*O=C`ZGW`P&J^`,"
MJI3^0Y.X\O^7=`$`M!,`@-(?(`/5HWIS^.(#&*IS!@"1X0,7JN`#%BI@`#_6
MGP(3ZR'__U3S4T&I]5M"J?=C0ZG]>\2HP`-?UA\@`]7``U_6'R`#U:,``+!C
M!$#YX/+_%_U[OZG]`P"1_7O!J,`#7]8``````0`"``````!P97)L>'-I+F,`
M````````7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````````
M`"X`````````+BX````````E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA
M3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(``````$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4`````&5X90``````+W!R;V,O)6DO)7,``````%!!4E]414U0````````
M``!005)?4%)/1TY!344`````.@`````````O`````````"5S)7,E<P``4$52
M3#5,24(``````````%!%4DQ,24(`4$523#5/4%0``````````%!%4DQ)3P``
M4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$``````!005)?0TQ%04X`````
M````4$%27T1%0E5'`````````%!!4E]#04-(10````````!005)?1TQ/0D%,
M7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@````````!005)?5$U0
M1$E2````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````
M`````%!!4E]#3$5!3CT````````Q`````````$Q$7TQ)0E)!4EE?4$%42`!3
M65-414T``"4P,G@`````<&%R+0`````E<R5S)7,E<P``````````)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U
M;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T
M:6]N*0H```````!0051(`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M
M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````````
M`$%21U8`````&`````````!P97)L`````#``````````4$%2.CI086-K97(Z
M.E9%4E-)3TX`````,2XP-#<```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I
M<F5C=&]R>0``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``````````+64`
M```````M+0```````%5315(`````55-%4DY!344``````````%1-4$1)4@``
M5$5-4$1)4@!414U0`````%1-4```````+W1M<`````!E=F%L("=E>&5C("]U
M<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N
M;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D
M<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.
M5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER
M(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ
M<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD
M.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@
M)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP
M("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI4
M96UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.
M3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL
M92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@
M7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]
M8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@
M(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T
M;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T
M;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@
M<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M
M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D
M969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI
M=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O
M;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O
M9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A
M=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E
M;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*
M;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@
M/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S
M:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R
M(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM
M>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E
M860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]
M/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD[
M"FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F
M9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S
M<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M
M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F
M9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@
M-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI
M<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L
M;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA
M;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD
M77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I
M(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L
M("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\
M86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B
M+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA
M;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE
M;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>
M+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D
M9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P
M-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R
M97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#
M86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L
M"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]
M"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?
M.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE
M;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*
M;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@
M=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O
M<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O
M)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/
M.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL
M92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M
M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E
M('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]
M+G!M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F
M:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I
M;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@
M9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR
M97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE
M=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B
M=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H
M+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C
M('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD
M<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T
M7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T
M*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I
M;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@
M('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR
M975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S
M:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*
M;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O
M7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@
M)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N
M<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O
M=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET
M92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*
M96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E
M<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#
M86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C
M86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]
M("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN
M:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C
M;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I
M(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I
M;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY
M("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R
M(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*
M8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^
M;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@
M97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@
M)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]
M?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A
M(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@
M9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO
M="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]
M"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD
M;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9
M*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*
M8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A
M=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@
M<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO
M861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L
M>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@
M)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@
M979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?
M14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B
M("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K
M*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG
M=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U
M;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I
M<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R
M97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP
M<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@
M9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)
M3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM
M>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H
M)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D
M;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@
M)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO
M:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF
M("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E
M9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI
M;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H
M(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@
M)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H
M1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*
M:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\
M:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T
M96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I
M;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H
M<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*
M)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?
M;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE
M7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D
M8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!
M+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I
M9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-
M1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A
M;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E
M<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*
M)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E
M*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C
M86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*
M?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N
M86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C
M:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE
M;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F
M:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N
M;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q
M=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR
M97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY
M("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D
M(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA
M;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"([
M"G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P
M<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO
M=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T
M(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE
M;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M
M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D
M;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF
M:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I
M/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E
M<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL
M("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]
M("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P
M:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T
M("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@
M(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X
M=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E
M<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@
M0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-
M;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM
M8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E
M4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA
M;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z
M.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P
M871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?
M;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E
M<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN
M9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I
M<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q
M=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![
M(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL
M('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE
M=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L
M('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*
M979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A
M8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!4
M35!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@
M+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T
M:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L
M('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF
M("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]
M("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@
M>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%
M3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S
M97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF
M:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY
M("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F
M:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D
M("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E
M96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]
M?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M
M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$
M:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R
M97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!]
M.PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)3
M24].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H
M85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M
M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N
M*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M
M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG
M97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM0
M05)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E
M;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S
M=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[
M4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B
M(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W
M<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D
M8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I
M9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I
M(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*
M<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'
M3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R
M;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%2
M7U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^
M/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D
M<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[
M4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE
M*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N
M9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T
M=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A
M=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6
M>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]
M?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA
M<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G
M;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D
M("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97
M:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO
M;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?
M9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H
M("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E
M;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!3
M4$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!
M4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W
M+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1?
M?2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!
M4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?
M0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@
M>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%
M3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P
M87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%
M04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]
M"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP
M<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*
M?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G
M<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C
M:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N
M9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E
M<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2
M+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E
M;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I
M<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64[
M"D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]
M"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*
M7U]%3D1?7PH```````$;`SOT````'0```&".__^D!@``V)#__PP!```(D?__
M(`$``$"1__\T`0``B)'__U@!``"0D?__<`$``&BB__^4`0``8*/___P!```(
MI/__+`(``$BF__]\`@``P*?__^@"``!8J/__$`,``(BI__]0`P``P*G__W`#
M```8JO__E`,``/"J___,`P``^*K__^`#```(K?__2`0``#BM__]<!```6*[_
M_Y`$```@L/__R`0``*BP___P!```V+#__Q@%``#(L?__3`4``*"Z___\!0``
MD+[__W0&```0O___Z`8``)"___\<!P``F+___S`'````````$``````````!
M>E(`!'@>`1L,'P`0````&````,2/__\L`````````!`````L````X(___S@`
M````````(````$`````$D/__2`````!!#B"=!)X#0I,"3M[=TPX`````%```
M`&0````HD/__!```````````````(````'P````8D/__U!````!!#J`%1IU4
MGE,#+`0*W=X.`$$+9````*````#,H/__]`````!!#D"=")X'0I,&E`5#F`&7
M`D26`Y4$5];50=C70][=T]0.`$$.0),&E`65!)8#EP*8`9T(G@=/UM5!V-=!
MWMW3U`X`00Y`DP:4!9T(G@="EP*8`4+8UP`L````"`$``%RA__^H`````$$.
M0)T(G@="E026`T23!I0%80K>W=76T]0.`$$+``!,````.`$``-2A__]``@``
M`$$.<)T.G@U"DPR4"T.5"I8)2Y<(F`>9!IH%`D`*WMW9VM?8U=;3U`X`00M)
MFP1@"MM!"TK;0IL$1-M#FP0``&@```"(`0``Q*/__W0!````00[@`9T<GAM"
MDQJ4&4>6%Y481-;51][=T]0.`$$.X`&3&I09E1B6%YT<GAM$F!67%D6:$YD4
M=`K6U4'8UT':V4$+0]76U]C9VD&6%Y4809@5EQ9!FA.9%````"0```#T`0``
MT*3__Y0`````00ZP`9T6GA5#DQ24$U<*WMW3U`X`00L\````'`(``$"E__\P
M`0```$(.T"!"G8H$GHD$0I.(!)2'!$.5A@26A01"EX0$F(,$:0K=WM?8U=;3
MU`X`00L`'````%P"```PIO__.`````!!#A"=`IX!2-[=#@`````@````?`(`
M`$BF__]4`````$$.()T$G@-"DP)*WMW3#@`````T````H`(``'RF___8````
M`$(.T$!"G8H(GHD(0I.(")2'"$.5A@B6A0AK"MW>U=;3U`X`00L``!````#8
M`@``'*?__P0`````````9````.P"```0I___#`(```!"#O`A09V>!)Z=!$*7
MF`28EP1#DYP$E)L$0YN4!%P*W=[;U]C3U`X`00M"EID$E9H$0IJ5!)F6!'P*
MUM5!VME!"U36U4':V4*6F025F@1!FI4$F98$```0````5`,``+BH__\L````
M`````#````!H`P``U*C__QP!````0@X@G02>`T*3`E@*WMW3#@!""V`*WMW3
M#@!!"T/>W=,.```T````G`,``,"I___$`0```$$.@`&=$)X/1),.E`U&E0R6
M"Y<*F`D"4`K>W=?8U=;3U`X`00L``"0```#4`P``4*O__X@`````00XPG0:>
M!4*3!)0#4`K>W=/4#@!!"P`D````_`,``+"K__\L`````$$.$)T"G@%%"M[=
M#@!""T+>W0X`````,````"0$``"XJ___[`````!!#E"="IX)0I,(E`=$E0:6
M!4*7!%<*WMW7U=;3U`X`00L``*P```!8!```=*S__]@(````0@[0@P)%G;@@
MGK<@0Y6T():S($*9L"":KR!&D[8@E+4@E[(@F+$@4P5(K"`%2:L@1IRM()NN
M(`):W-M0!D@&2=W>V=K7V-76T]0.`$$.T(,"D[8@E+4@E;0@EK,@E[(@F+$@
MF;`@FJ\@FZX@G*T@G;@@GK<@!4BL(`5)JR`">PK<VT$+8=S;1INN()RM(`+`
M"MS;00MZV]Q!G*T@FZX@=`````@%``"<M/__[`,```!!#H`!G1">#T.7"I@)
M0I,.E`U%E0R6"YD(F@>;!IP%8`5)`P5(!'0&209(`E@*WMW;W-G:U]C5UM/4
M#@!!"T,%2`0%20-1!DD&2$T%20,%2`1)!D@&24\*!4D#!4@$00M"!4D#!4@$
M+````(`%```4N/__@`````!!#B"=!)X#0I,"E`%0"M[=T]0.`$$+2][=T]0.
M````0````+`%``"TA___*`(```!!#G"=#IX-0I,,E`M+E0J6"4Z7"`),UT'>
MW=76T]0.`$$.<),,E`N5"I8)G0Z>#467"``P````]`4``""X__]\`````$$.
M0)T(G@="DP:4!4.5!)8#19<"F`%3WMW7V-76T]0.````$````"@&``!LN/__
M!``````````0````/`8``&"X__\,````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`*@C````````8",````````!``````````$``````````0````````"\`0``
M``````$`````````"P(````````!`````````&0#````````#`````````!(
M'`````````T`````````Q%$````````9`````````#B;`0``````&P``````
M```(`````````!H`````````0)L!```````<``````````@`````````]?[_
M;P````"8`@````````4`````````B`T````````&`````````(`#````````
M"@````````#C!`````````L`````````&``````````5````````````````
M`````P````````!HG0$```````(```````````8````````4``````````<`
M````````%P````````!(%@````````<`````````J!,````````(````````
M`*`"````````"0`````````8`````````!X`````````"`````````#[__]O
M``````$```@`````_O__;P````!($P```````/___V\``````P````````#P
M__]O`````&P2````````^?__;P`````0````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M8!P```````!@'````````&`<````````8!P```````!@'````````&`<````
M````8!P```````!@'````````&`<````````8!P```````!@'````````&`<
M````````8!P```````!@'````````&`<````````8!P```````!@'```````
M`&`<````````8!P```````!@'````````&`<````````8!P```````!@'```
M`````&`<````````8!P```````!@'````````&`<````````8!P```````!@
M'````````&`<````````8!P```````!@'````````&`<````````8!P`````
M``!@'````````&`<````````8!P```````!@'````````&`<````````8!P`
M``````!@'````````&`<````````8!P```````!@'````````&`<````````
M8!P```````!@'````````&`<````````8!P```````!@'````````&`<````
M````8!P```````!@'````````&`<````````8!P```````!@'````````&`<
M````````8!P```````!@'````````&`<````````8!P```````!@'```````
M`&`<````````8!P```````!(FP$``````+!1````````````````````````
M````````````````````````````````````````````````````````````
M`````````#!1``````````````````"`(```````````````````````````
M````````````````````````"*`!``````#_____`````.!5````````&%(`
M`````````````````'A3````````P%4```````#(50```````-!5````````
MV%4``````````````````*A5````````L%4``````````````````.A5````
M````1T-#.B`H56)U;G1U(#@N,BXP+3$P=6)U;G1U,2D@."XR+C```"YS:'-T
M<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N
M=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I
M;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A
M>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE
M;G0`````````````````````````````````````````````````````````
M````````````````````````````````"P````$````"`````````#@"````
M````.`(````````;`````````````````````0```````````````````!,`
M```'`````@````````!4`@```````%0"````````(```````````````````
M``0````````````````````A````!P````(`````````=`(```````!T`@``
M`````"0````````````````````$````````````````````-````/;__V\"
M`````````)@"````````F`(```````#D``````````4`````````"```````
M`````````````#X````+`````@````````"``P```````(`#````````"`H`
M```````&`````P````@`````````&`````````!&`````P````(`````````
MB`T```````"(#0```````.,$```````````````````!````````````````
M````3@```/___V\"`````````&P2````````;!(```````#6``````````4`
M`````````@`````````"`````````%L```#^__]O`@````````!($P``````
M`$@3````````8``````````&`````P````@```````````````````!J````
M!`````(`````````J!,```````"H$P```````*`"````````!0`````````(
M`````````!@`````````=`````0```!"`````````$@6````````2!8`````
M````!@````````4````5````"``````````8`````````'X````!````!@``
M``````!('````````$@<````````%`````````````````````0`````````
M``````````!Y`````0````8`````````8!P```````!@'````````"`$````
M```````````````0`````````!``````````A`````$````&`````````(`@
M````````@"````````!$,0``````````````````"```````````````````
M`(H````!````!@````````#$40```````,11````````$```````````````
M``````0```````````````````"0`````0````(`````````V%$```````#8
M40```````$A````````````````````(````````````````````F`````$`
M```"`````````""2````````()(```````#T````````````````````!```
M`````````````````*8````!`````@`````````8DP```````!B3````````
M4`8```````````````````@```````````````````"P````#@````,`````
M````.)L!```````XFP````````@````````````````````(``````````@`
M````````O`````\````#`````````$";`0``````0)L````````(````````
M````````````"``````````(`````````,@````&`````P````````!(FP$`
M`````$B;````````(`(````````&``````````@`````````$`````````#1
M`````0````,`````````:)T!``````!HG0```````)@"````````````````
M```(``````````@`````````U@````$````#``````````"@`0```````*``
M``````"`````````````````````"````````````````````-P````(````
M`P````````"`H`$``````("@````````*!````````````````````@`````
M``````````````#A`````0```#````````````````````"`H````````"0`
M```````````````````!``````````$``````````0````,`````````````
M````````````I*````````#J`````````````````````0``````````````
$````````
